flutter_test_patterns
library
Classes
-
InteractionContract
-
Represents a single interaction contract that a widget must satisfy.
Functions
-
goldenVariants(WidgetTester tester, String name, {required Map<String, Widget Function()> variants, Size? surfaceSize, Color? backgroundColor, bool wrapWithMaterialApp = true})
→ Future<void>
-
Runs golden tests for multiple variants of a widget.
-
testInteractionContract(WidgetTester tester, {required Widget build(), required List<InteractionContract> contracts})
→ Future<void>
-
Runs a list of interaction contracts against a widget.
-
testStateMatrix(WidgetTester tester, String name, {required Map<String, Widget Function()> states, required void verify(String stateName), bool wrapWithMaterialApp = true})
→ Future<void>
-
Tests a widget across a matrix of states using a custom verification callback.