interaction_contracts library

Classes

InteractionContract
Represents a single interaction contract that a widget must satisfy.

Functions

testInteractionContract(WidgetTester tester, {required Widget build(), required List<InteractionContract> contracts}) Future<void>
Runs a list of interaction contracts against a widget.